@@ -2,12 +2,12 @@ import os
 
 import pytest
 
-from twine.commands import _find_dists, _group_wheel_files_first
+from twine import commands
 from twine import exceptions
 
 
 def test_ensure_wheel_files_uploaded_first():
-    files = _group_wheel_files_first(
+    files = commands._group_wheel_files_first(
         ["twine/foo.py", "twine/first.whl", "twine/bar.py", "twine/second.whl"]
     )
     expected = [
@@ -20,13 +20,13 @@ def test_ensure_wheel_files_uploaded_first():
 
 
 def test_ensure_if_no_wheel_files():
-    files = _group_wheel_files_first(["twine/foo.py", "twine/bar.py"])
+    files = commands._group_wheel_files_first(["twine/foo.py", "twine/bar.py"])
     expected = ["twine/foo.py", "twine/bar.py"]
     assert expected == files
 
 
 def test_find_dists_expands_globs():
-    files = sorted(_find_dists(["twine/__*.py"]))
+    files = sorted(commands._find_dists(["twine/__*.py"]))
     expected = [
         os.path.join("twine", "__init__.py"),
         os.path.join("twine", "__main__.py"),
@@ -36,7 +36,7 @@ def test_find_dists_expands_globs():
 
 def test_find_dists_errors_on_invalid_globs():
     with pytest.raises(exceptions.InvalidDistribution):
-        _find_dists(["twine/*.rb"])
+        commands._find_dists(["twine/*.rb"])
 
 
 def test_find_dists_handles_real_files():
@@ -47,5 +47,5 @@ def test_find_dists_handles_real_files():
         "twine/utils.py",
         "twine/wheel.py",
     ]
-    files = _find_dists(expected)
+    files = commands._find_dists(expected)
     assert expected == files
