@@ -7,7 +7,6 @@ import secrets
 import subprocess
 import sys
 
-import colorama
 import jaraco.envs
 import munch
 import portend
@@ -17,7 +16,10 @@ import requests
 from twine import __main__ as dunder_main
 from twine import cli
 
-pytestmark = [pytest.mark.enable_socket, pytest.mark.flaky(reruns=3, reruns_delay=1)]
+pytestmark = [
+    pytest.mark.enable_socket,
+    pytest.mark.flaky(reruns=3, reruns_delay=1),
+]
 
 
 @pytest.fixture(scope="session")
@@ -28,7 +30,7 @@ def sampleproject_dist(tmp_path_factory):
     )
     with (checkout / "setup.py").open("r+") as setup:
         orig = setup.read()
-        sub = orig.replace("name='sampleproject'", "name='twine-sampleproject'")
+        sub = orig.replace('name="sampleproject"', 'name="twine-sampleproject"')
         assert orig != sub
         setup.seek(0)
         setup.write(sub)
@@ -64,7 +66,7 @@ def test_pypi_upload(sampleproject_dist):
     cli.dispatch(command)
 
 
-def test_pypi_error(sampleproject_dist, monkeypatch):
+def test_pypi_error(sampleproject_dist, monkeypatch, capsys):
     command = [
         "twine",
         "upload",
@@ -79,14 +81,16 @@ def test_pypi_error(sampleproject_dist, monkeypatch):
     monkeypatch.setattr(sys, "argv", command)
 
     message = (
-        re.escape(colorama.Fore.RED)
-        + r"HTTPError: 403 Forbidden from https://test\.pypi\.org/legacy/\n"
-        + r".+?authentication"
+        r"HTTPError: 403 Forbidden from https://test\.pypi\.org/legacy/"
+        + r".+authentication information"
     )
 
-    result = dunder_main.main()
+    error = dunder_main.main()
+    assert error
 
-    assert re.match(message, result)
+    captured = capsys.readouterr()
+
+    assert re.search(message, captured.out, re.DOTALL)
 
 
 @pytest.fixture(
