@@ -1,7 +1,6 @@
 import functools
 import getpass
 import logging
-import warnings
 from typing import Callable, Optional, Type, cast
 
 import keyring
@@ -29,7 +28,7 @@ class Resolver:
     def choose(cls, interactive: bool) -> Type["Resolver"]:
         return cls if interactive else Private
 
-    @property  # type: ignore  # https://github.com/python/mypy/issues/1362
+    @property
     @functools.lru_cache()
     def username(self) -> Optional[str]:
         return utils.get_userpass_value(
@@ -39,7 +38,7 @@ class Resolver:
             prompt_strategy=self.username_from_keyring_or_prompt,
         )
 
-    @property  # type: ignore  # https://github.com/python/mypy/issues/1362
+    @property
     @functools.lru_cache()
     def password(self) -> Optional[str]:
         return utils.get_userpass_value(
@@ -55,21 +54,26 @@ class Resolver:
 
     def get_username_from_keyring(self) -> Optional[str]:
         try:
-            creds = keyring.get_credential(self.system, None)
+            system = cast(str, self.system)
+            logger.info("Querying keyring for username")
+            creds = keyring.get_credential(system, None)
             if creds:
                 return cast(str, creds.username)
         except AttributeError:
             # To support keyring prior to 15.2
             pass
         except Exception as exc:
-            warnings.warn(str(exc))
+            logger.warning("Error getting username from keyring", exc_info=exc)
         return None
 
     def get_password_from_keyring(self) -> Optional[str]:
         try:
-            return cast(str, keyring.get_password(self.system, self.username))
+            system = cast(str, self.system)
+            username = cast(str, self.username)
+            logger.info("Querying keyring for password")
+            return cast(str, keyring.get_password(system, username))
         except Exception as exc:
-            warnings.warn(str(exc))
+            logger.warning("Error getting password from keyring", exc_info=exc)
         return None
 
     def username_from_keyring_or_prompt(self) -> str:
